# タスク設計書の保存先

このディレクトリにタスク設計書を保存する。

- 全タスク依頼で、作業開始前にタスク設計書の作成を必須とする。
- 保存先: `docs/task-designs/`
- 命名規則: `YYYYMMDDHHMMSS_{task-name}.md`
- 時刻: 初版作成日時（JST）
- `task-name`: 英小文字の kebab-case
- 更新時: 原則ファイル名を変更しない
